
.. _properties:

.. currentmodule:: jgrapht.properties

Structural Properties
*********************

The following functions allow the user to check for certain structural graph properties.

.. automodule:: jgrapht.properties
   :members:
